import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

/**
 * A thing that can move around with a certain speed.
 * 
 * @author Poul Henriksen
 */
public abstract class MovingThing extends Actor
{
    private double speedx = 0;
    private double speedy = 0;

    public MovingThing()
    {
    }
    
    // Use random direction
    public MovingThing(double speed)
    {
        int direction = Greenfoot.getRandomNumber(360);
        accelerateDirection(direction, speed);
    }
    
    /**
     * Create new thing initialised with given speed.
     */
    public MovingThing(double speedx, double speedy)
    {
        this.speedx = speedx;
        this.speedy = speedy;
    }
    
    /**
     * Move forward one step.
     */
    public void moveAtSpeed() {
        int x = getX() + (int)speedx;
        int y = getY() + (int)speedy;
        if(x >= getWorld().getWidth()) {
            x -= getWorld().getWidth();
        }
        if(x < 0) {
            x += getWorld().getWidth();
        }
        if(y >= getWorld().getHeight()) {
            y -= getWorld().getHeight();
        }
        if(y < 0) {
            y += getWorld().getHeight();
        }
        setLocation(x, y);
    }
    
    /**
     * Increase the speed with the given vector.
     */
    public void increaseSpeed(double accx, double accy) {
        speedx += accx;
        speedy += accy;
    }
    
    public void accelerateDirection(int direction, double amount) {
        speedx += amount * Math.cos(Math.toRadians(direction));
        speedy += amount * Math.sin(Math.toRadians(direction));
    }
    
    /**
     * Return the current speed.
     */
    public double getSpeedX() {
        return speedx;
    }
    
    public double getSpeedY() {
        return speedy;
    }
}